.dizmo-checkbox-input {
    display: none;
}

.dizmo-checkbox-input:checked + .dizmo-checkbox-label span.dizmo-checkbox-label-image {
    background: url(unchecked.svg) left top no-repeat;
}

.dizmo-checkbox-label span.dizmo-checkbox-label-image {
    margin-right: 10px;
    width: 25px;
    height: 25px;
    background: url(checked.svg) left top no-repeat;
}

.dizmo-checkbox-label span {
    display: inline-block;
    vertical-align: middle;
}

.dizmo-checkbox-label {
    font-family: "Pharma-RegularCon";
    font-weight: normal;
    cursor: pointer;
    vertical-align: middle;
    color: rgb(237, 237, 237);
}
