.dizmo-slider-parent {
    border: 1px solid rgb(237, 237, 237);
    padding: 25px;
    border-radius: 10px;
}

.dizmo-slider-parent.orientation-horizontal {
    height: 2px;
}

.dizmo-slider-parent.orientation-vertical {
    width: 2px;
}

.dizmo-slider-parent .dizmo-slider {
    background: none;
    background-color: rgba(237, 237, 237, 1);
    border: none;
    width: 100%;
    -apple-dashboard-region: dashboard-region(control rectangle);
}

.dizmo-slider-parent .dizmo-slider a.ui-slider-handle {
    background: url(handle.svg) no-repeat;
    border: none;
    width: 20px;
    height: 20px;
    outline: none;
    -apple-dashboard-region: dashboard-region(control rectangle);
}

.dizmo-slider-parent.orientation-vertical .dizmo-slider {
    width: 2px;
}

.dizmo-slider-parent.orientation-vertical .dizmo-slider a.ui-slider-handle {
    left: -9px;
}

.dizmo-slider-parent.orientation-horizontal .dizmo-slider {
    height: 2px;
}

.dizmo-slider-parent.orientation-horizontal .dizmo-slider a.ui-slider-handle {
    top: -9px;
}
