button.dizmo-switch {
    outline: none;
    border: none;
    background: none;
    background-image: url('background.svg');
    width: 138px;
    height: 65px;
    padding: 0px;
    position: relative;
}

button.dizmo-switch span.dizmo-switch-image {
    width: 70px;
    height: 65px;
    display: inline-block;
    position: absolute;
    top: 0px;
    background-repeat: no-repeat;
}

button.dizmo-switch span.dizmo-switch-off-image {
    background-image: url('off.svg');
}

button.dizmo-switch span.dizmo-switch-on-image {
    background-image: url('on.svg');
}

button.dizmo-switch-on span.dizmo-switch-on-image {
    -webkit-transition: left 0.5s, opacity 0.5s;
    left: 68px;
    opacity: 1;
}

button.dizmo-switch-on span.dizmo-switch-off-image {
    -webkit-transition: left 0.5s, opacity 0.5s;
    left: 68px;
    opacity: 0;
}

button.dizmo-switch-off span.dizmo-switch-on-image {
    -webkit-transition: left 0.5s, opacity 0.5s;
    left: 0px;
    opacity: 0;
}

button.dizmo-switch-off span.dizmo-switch-off-image {
    -webkit-transition: left 0.5s, opacity 0.5s;
    left: 0px;
    opacity: 1;
}
